container_idents_match

Function container_idents_match 

fn container_idents_match(a: &TypePath, b: &TypePath) -> bool
Compare two container type paths by their ident segments (ignoring lifetimes and generic arguments). Two containers are “same” if their path idents match.

This is safe because after erasure all container types have the same generic arity (lifetimes + Datum<'a>), so ident equality implies structural equality.