elide_lifetimes

Function elide_lifetimes 

fn elide_lifetimes(tp: &TypePath) -> TypePath
Replaces all lifetime parameters in a syn::TypePath with '_.

Used for container type paths in turbofish position (e.g. <DatumList<'_, Datum<'_>> as SqlContainerType>::...). The output_sql_type method’s &self provides an implicit lifetime that the compiler can infer through '_.