erase_generic_param

Function erase_generic_param 

fn erase_generic_param(ty: &Type, generic_name: &Ident) -> Type
Replaces occurrences of a generic type parameter with Datum<'a> in a type.

Used to convert types from the user’s generic function signature into concrete types for the generated trait impl’s associated types, where T is not in scope.